//
//  iPadViewController.m
//  CCProcessingCustom
//
//  Created by USAePay on 4/28/14.
//  Copyright (c) 2014 USAePay. All rights reserved.
//

#import "iPadViewController.h"
#import "USAePayLibraryUeConnection.h"

#import "USAePayLibraryUesoapTransactionResponse.h" //Needed to output the result response
#import "USAePayLibraryConstants.h"

@interface iPadViewController ()

@end

@implementation iPadViewController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    USAePayLibraryConstants *shareManager = [USAePayLibraryConstants sharedManager];
    
    /*
     * This are the required information, which need to initialize
     * Before doing any transactions
     */
    shareManager.isProduction = true;
    shareManager.sourceKey = @"Your Source Key";
    shareManager.pinNum = @"Your Pin";
    
    /*
     * Delegate all the textfield to use the textfield call back methods
     */
    chargeAmount.delegate = self;
    invoiceNumber.delegate = self;
    fullName.delegate = self;
    cardNumber.delegate = self;
    expDate.delegate = self;
    cvvNumber.delegate = self;
    addressVerif.delegate = self;
    zipVerif.delegate = self;
    
    /*
     * Initialize the credit card payment, and sets delegate to self so the call back methods will get call
     */
    _ccPayment = [[USAePayLibraryCreditCardPayment alloc]init];
    _ccPayment.delegate = self;
    
    /*
     * Sets the scroll view content size to allow user to scroll the fields up and down
     */
    [scrollView setContentSize:CGSizeMake(768, 1200)];
   
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

-(BOOL)textFieldShouldReturn:(UITextField *)textField
{
    [textField resignFirstResponder];
    return YES;
}

-(IBAction)payBtn:(id)sender
{
    UIAlertView *paymentAlert;
    
    /*
     * Check to see if there is internet connection before processin any payments
     */
    if([USAePayLibraryUeConnection isConnected])
    {
        /*
         * Check to make sure all the required fields are filled in
         * In addition, use our credit card verify method and expiration date verify method
         * To make sure the credit card number and expiration date are valid
         */
        
        if(fullName.text.length==0)
        {
            paymentAlert = [[UIAlertView alloc]initWithTitle:@"Field empty" message:@"Please enter credit card holder's name" delegate:self cancelButtonTitle:@"Ok" otherButtonTitles:nil, nil];
            [paymentAlert show];
        }
        
        else if(cardNumber.text.length==0 || ![_ccPayment verifyCreditCard:cardNumber.text])
        {
            paymentAlert = [[UIAlertView alloc]initWithTitle:@"Credit card field" message:@"Invalid credit card number" delegate:self cancelButtonTitle:@"Ok" otherButtonTitles:nil, nil];
            [paymentAlert show];
        }
        
        else if(expDate.text.length==0 || ![_ccPayment verifyExpDate:expDate.text])
        {
            paymentAlert = [[UIAlertView alloc]initWithTitle:@"Expiration date field" message:@"Invalid credit card expiration date" delegate:self cancelButtonTitle:@"Ok" otherButtonTitles:nil, nil];
            [paymentAlert show];
        }
        
        else if(cvvNumber.text.length==0 || cvvNumber.text.length < 3)
        {
            paymentAlert = [[UIAlertView alloc]initWithTitle:@"CCV field" message:@"Invalid CVV number" delegate:self cancelButtonTitle:@"Ok" otherButtonTitles:nil, nil];
            [paymentAlert show];
        }
        
        else if(addressVerif.text.length==0)
        {
            paymentAlert = [[UIAlertView alloc]initWithTitle:@"Field empty" message:@"Please enter a street address" delegate:self cancelButtonTitle:@"Ok" otherButtonTitles:nil, nil];
            [paymentAlert show];
        }
        
        else if(zipVerif.text.length==0 || zipVerif.text.length < 5 || zipVerif.text.length > 5)
        {
            paymentAlert = [[UIAlertView alloc]initWithTitle:@"Zip verificaiton field" message:@"Invalid zip code" delegate:self cancelButtonTitle:@"Ok" otherButtonTitles:nil, nil];
            [paymentAlert show];
        }
        
        else if(chargeAmount.text.length==0)
        {
            paymentAlert = [[UIAlertView alloc]initWithTitle:@"Charge amount field" message:@"Need to enter a charge amount" delegate:self cancelButtonTitle:@"Ok" otherButtonTitles:nil, nil];
            [paymentAlert show];
        }

        else
        {
            [loadingIndicator startAnimating];
            
            /*
             * Before we call the process payment method,
             * We need to set the required values in credit card payment class
             */
            
            _ccPayment.usaepayLibraryCreditCardHolderName = fullName.text;
            _ccPayment.usaepayLibraryCreditCardNumber = cardNumber.text;
            _ccPayment.usaepayLibraryCreditCardExpDate = expDate.text;
            _ccPayment.usaepayLibraryCreditCardCVV = cvvNumber.text;
            _ccPayment.usaepayLibraryCreditCardAvsStreet = addressVerif.text;
            _ccPayment.usaepayLibraryCreditCardAvsZip = zipVerif.text;
            _ccPayment.usaepayLibraryCreditCardChargeAmount = chargeAmount.text;
            
            /*
             *The invoice number is an option field
             */
            _ccPayment.usaepayLibraryInvoiceNumber = invoiceNumber.text;
            
            [_ccPayment processCCPayment];
        }
    }
    
    else
    {
        /*
         * If there is no internet connection, alert the user
         */
        
        paymentAlert = [[UIAlertView alloc]initWithTitle:@"No connection" message:@"Please connect to the internet!" delegate:self cancelButtonTitle:@"Ok" otherButtonTitles:nil, nil];
        
        [paymentAlert show];
    }
}

/*
 * Once the payment is finished processing
 * This method gets call, resultMsg holds the status of the process payment
 * Such as payment approved, failed, there was an error in the payment and etc..
 */
-(void)finishProcessingPayment :(USAePayLibraryUesoapTransactionResponse *)response
{
    
    [loadingIndicator stopAnimating];
    
    /*
     * Use an alert to display the payment result status
     */
    
    UIAlertView *paymentResult = [[UIAlertView alloc]initWithTitle:@"Payment status" message:response.Result delegate:self cancelButtonTitle:@"Ok" otherButtonTitles:nil, nil];
    
    [paymentResult show];
}

@end
